
Welcome to Sentaku's documentation!
=====================================

Sentaku is a experiment for acceptance testing.

Sentaku provides a easy way to describe applications and use-cases
while being able to choose implementations and fall back between them.


Contents:

.. toctree::
   :maxdepth: 2

   about
   getting_started
   the_parts
   extra_api
   examples



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
